@@ -3,7 +3,7 @@ import tkinter as Tk
 from tkinter import filedialog
 import matplotlib
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg, NavigationToolbar2Tk
-import df_manipulation as df
+import MASTUDMSGUI.df_manipulation as df
 import pandas as pd
 import time
 from matplotlib.widgets import Slider, RectangleSelector
@@ -1089,7 +1089,7 @@ def submit_shot_selection():
 def run_program():
     click.echo('hello world')
 
-    
+
 if __name__ == "__main__":
 
 
